
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
    <script>
import extend from "@/extension/record/locationStatusChangeRecord.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "货位状态变动记录",
      name: "locationStatusChangeRecord",
      url: "/LocationStatusChangeRecord/",
      sortName: "id",
    });
    const editFormFields = ref({
      deviceCode: "",
      deviceName: "",
      deviceType: "",
      deviceStatus: "",
      deviceIp: "",
      devicePort: "",
      devicePlcType: "",
      deviceRemark: "",
    });
    const editFormOptions = ref([]);
    const searchFormFields = ref({
      locationCode: "",
      orderNo: "",
      taskNum: "",
    });
    const searchFormOptions = ref([
      [
        { title: "货位号", field: "locationCode" },
        { title: "单据编号", field: "orderNo" },
        { title: "任务号", field: "taskNum" },
      ],
      [
        {
          title: "变动前货位状态",
          field: "beforeStatus",
          type: "selectList",
          dataKey: "locationStatusEnum",
          data: [],
        },
        {
          title: "变动后货位状态",
          field: "afterStatus",
          type: "selectList",
          dataKey: "locationStatusEnum",
          data: [],
        },
        {
          title: "变动类型",
          field: "changeType",
          type: "selectList",
          dataKey: "locationChangeType",
          data: [],
        },
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "locationId",
        title: "货位主键",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "taskNum",
        title: "任务号",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "locationCode",
        title: "货位编号",
        type: "string",
        width: 150,
        align: "left",
      },
      {
        field: "beforeStatus",
        title: "变动前货位状态",
        type: "string",
        width: 150,
        align: "left",
        bind: { key: "locationStatusEnum", data: [] },
      },
      {
        field: "afterStatus",
        title: "变动后货位状态",
        type: "decimal",
        width: 150,
        align: "left",
        bind: { key: "locationStatusEnum", data: [] },
      },
      {
        field: "changeType",
        title: "变动类型",
        type: "string",
        width: 90,
        align: "left",
        bind: { key: "locationChangeType", data: [] },
      },
      {
        field: "orderId",
        title: "单据主键",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "orderNo",
        title: "单据编号",
        type: "int",
        width: 120,
        align: "left",
      },
      {
        field: "orderDetailId",
        title: "单据明细主键",
        type: "string",
        width: 200,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "#detailCnName",
      table: "",
      columns: [],
      sortName: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
    